componenttools.get_first_instance_of_klass_in_improper_parentage_of_component
=============================================================================

.. autofunction:: abjad.tools.componenttools.get_first_instance_of_klass_in_improper_parentage_of_component.get_first_instance_of_klass_in_improper_parentage_of_component
